#!/bin/bash

source site-options.conf

#
# call script to install StackStorm
#
./bash/DontRunDirectly.sh --version=$VERSION --user=$ACTIONFLOW_USER --password=$ACTIONFLOW_PASSWORD
if [ $? != 0 ]
then
  echo "Error during StackStorm installation"
  exit 1
fi

#
# install RPMs
#
yum -y install gcc libffi-devel python-devel openssl-devel policycoreutils-python java-1.7.0-openjdk nc 

#
# set environment variable
#
echo "export ST2_AUTH_TOKEN=$(st2 auth $ACTIONFLOW_USER -p $ACTIONFLOW_PASSWORD -t)" > /etc/profile.d/global.sh
export ST2_AUTH_TOKEN=$(st2 auth $ACTIONFLOW_USER -p $ACTIONFLOW_PASSWORD -t)

#
# encrypt db
#
mkdir -p /etc/st2/keys
st2-generate-symmetric-crypto-key --key-path /etc/st2/keys/datastore_key.json
usermod -a -G st2 st2
chown -R st2:st2 /etc/st2/keys
chmod o-r /etc/st2/keys
chmod o-r /etc/st2/keys/datastore_key.json
cat << EOF >> /etc/st2/st2.conf

[keyvalue]
encryption_key_path = /etc/st2/keys/datastore_key.json
EOF
st2ctl restart

#
# set st2 keys
#
st2 key set rabbitmq_host $EVENTQ_HOST
st2 key set rabbitmq_user $AMQP_USER
st2 key set rabbitmq_password $AMQP_PASSWORD --encrypt
st2 key set ws_queue $WORKFLOW_QUEUE
st2 key set actions_queue $ACTION_QUEUE
st2 key set ws_queue $WS_QUEUE
st2 key set st2_user $ACTIONFLOW_USER
st2 key set st2_password $ACTIONFLOW_PASSWORD --encrypt

#
# set rules
#
cd /opt/stackstorm/packs/actionhub/rules
st2 rule create actions_query_rule.yaml
st2 rule create wsqueuelistener.yaml

#
# restart
#
st2ctl restart

#
# install packs
#
st2 run packs.setup_virtualenv packs=actionhub
st2 run packs.setup_virtualenv packs=ansible
st2 run packs.setup_virtualenv packs=appdynamics
st2 run packs.setup_virtualenv packs=chef
st2 run packs.setup_virtualenv packs=collabnet-aws
st2 run packs.setup_virtualenv packs=collabnet-build-flows
st2 run packs.setup_virtualenv packs=collabnet-commit-flows
st2 run packs.setup_virtualenv packs=collabnet-core
st2 run packs.setup_virtualenv packs=collabnet-custom-flows
st2 run packs.setup_virtualenv packs=collabnet-generic-flows
st2 run packs.setup_virtualenv packs=collabnet-jenkins
st2 run packs.setup_virtualenv packs=collabnet-jira
st2 run packs.setup_virtualenv packs=collabnet-jira-servicedesk
st2 run packs.setup_virtualenv packs=collabnet-linux
st2 run packs.setup_virtualenv packs=collabnet-review-flows
st2 run packs.setup_virtualenv packs=collabnet-servicenow
st2 run packs.setup_virtualenv packs=collabnet-slack
st2 run packs.setup_virtualenv packs=collabnet-teamforge-cli
st2 run packs.setup_virtualenv packs=collabnet-utilities
st2 run packs.setup_virtualenv packs=collabnet-workitem-flows
st2 run packs.setup_virtualenv packs=docker
st2 run packs.setup_virtualenv packs=newrelic
st2 run packs.setup_virtualenv packs=puppet
st2 run packs.setup_virtualenv packs=rabbitmq
st2 run packs.setup_virtualenv packs=salt
st2 run packs.setup_virtualenv packs=sonarqube
st2 run packs.setup_virtualenv packs=splunk
st2 run packs.setup_virtualenv packs=teamforge
st2 run packs.setup_virtualenv packs=tfs
st2 run packs.setup_virtualenv packs=ubuild
st2 run packs.setup_virtualenv packs=udeploy
st2 run packs.setup_virtualenv packs=xldeploy
st2 run packs.setup_virtualenv packs=xml
st2 run packs.setup_virtualenv packs=zap

#
# reload
#
st2ctl reload --register-all
st2ctl reload --register-configs
st2ctl restart-component st2sensorcontainer

#
# enable st2 when SELinux enforce
#
setsebool -P httpd_can_network_connect 1

#
# uncompress tar ball
#
cd /opt
tar xvfz zookeeper-3.4.9.tar.gz

#
# copy zookeeper conf file
#
cp -f /opt/zookeeper-3.4.9/conf/zoo_sample.cfg /opt/zookeeper-3.4.9/conf/zoo.cfg

#
# replace first line of zookeeper shell script
#
sed -i "s|#!/usr/bin/env bash|#!/bin/bash|" /opt/zookeeper-3.4.9/bin/zkServer.sh

#
# change protections in zookeeper
#
chmod -R 750 /opt/zookeeper-3.4.9

#
# enable zookeper service
#
systemctl daemon-reload
systemctl enable zookeeper.service

#
# restart machine
#
echo " "
echo "+---------------------------------------------------+"
echo "| The machine will reboot now, please press <enter> |"
echo "+---------------------------------------------------+"
read
shutdown -r now
