from lib.base import ServiceDeskAction


class CreateServicedeskRequestAction(ServiceDeskAction):

    def run(self, summary, description=None, labels=None):
        # Service desk id and request type id will likely never change. If
        # necessary, they can be overridden by adding 'serviceDeskId' and
        # 'requestTypeId' fields to the pack config. Consult the JIRA
        # servicedesk server (NOT cloud) api docs for more details.
        service_desk_id = 1 or self.config.get('serviceDeskId')
        request_type_id = 1 or self.config.get('requestTypeId')
        create_data = {
            'serviceDesk': service_desk_id,
            'requestType': request_type_id,
            'requestFieldValues': {
                'summary': summary
            }
        }
        if description:
            create_data['requestFieldValues']['description'] = description

        create_resp = self.post('/rest/servicedeskapi/request', data=create_data)
        create_result = create_resp.json()

        if labels:
            # Add the release-blocker label to the query's associated issue.
            issue_endpoint = '/rest/api/2/issue/{}'.format(create_result.get('issueId'))

            update_data = {
                'update': {
                    'labels': [{'set': labels}]
                }
            }
            update_resp = self.put(issue_endpoint, data=update_data)

        return create_result
