import json
import requests
from jira import JIRA
from requests.auth import HTTPBasicAuth
from urlparse import urljoin

from st2actions.runners.pythonrunner import Action


class ServiceDeskAction(Action):
    def __init__(self, config):
        super(ServiceDeskAction, self).__init__(config=config)
        self._base_url = self.config['host']
        self._username = self.config['username']
        self._password = self.config['password']
        self._auth = HTTPBasicAuth(self._username, self._password)
        self._client = JIRA(self._base_url, basic_auth=(self._username, self._password))

    def post(self, endpoint, data=None):
        headers = {
            'Content-Type': 'application/json',
            'X-ExperimentalApi': 'opt-in'
        }
        url = urljoin(self._base_url, endpoint)
        resp = requests.post(url,
                             data=json.dumps(data),
                             auth=self._auth,
                             headers=headers)
        resp.raise_for_status()
        return resp

    def put(self, endpoint, data=None):
        headers = {
            'Content-Type': 'application/json',
            'X-ExperimentalApi': 'opt-in'
        }
        url = urljoin(self._base_url, endpoint)
        resp = requests.put(url,
                            data=json.dumps(data),
                            auth=self._auth,
                            headers=headers)
        resp.raise_for_status()
        return resp

    def get(self, endpoint, params=None):
        headers = {
            'Content-Type': 'application/json',
            'X-ExperimentalApi': 'opt-in'
        }
        url = urljoin(self._base_url, endpoint)
        resp = requests.get(url, params=params, headers=headers)
        resp.raise_for_status()
        return resp
