import requests
import json


from lib.udeploy_action import UDeployAction


class DeployAction(UDeployAction):
    def run(self, application, application_process=None, environment=None):
        """
        Launch a deployment.

        :return: the request id for the deployment
        :rtype: str
        """
        url = '{0}/cli/applicationProcessRequest/request'.format(self._base_url)
        try:
            appConfig = self.config.get('applications').get(application)
        except AttributeError:
            appConfig = None
        if appConfig:
            #print(appConfig.get('process'))
            application_process = application_process or appConfig.get('process')
            environment = environment or appConfig.get('defaultEnv')

        if not application_process:
            raise ValueError('An application process must be defined either in config ' +
                             'or in the deploy command.')
        if not environment:
            raise ValueError('An environment must be defined either in config ' + 
                             'or in the deploy command.')

        payload = {
            'application': application,
            'applicationProcess': application_process,
            'environment': environment,
            'versions': self._create_component_versions_array(application)
        }
        req = requests.put(url,
                           headers=self._auth_headers,
                           data=json.dumps(payload),
                           verify=False)
        request_id = req.json()['requestId']
        return {'request_id': request_id}

    def _create_component_versions_array(self, application):
        components = self._get_all_components_for_application(application)
        return [{'component': x, 'version': 'latest'} for x in components]

    def _get_all_components_for_application(self, application):
        url = '{0}/cli/application/componentsInApplication'.format(self._base_url)

        req = requests.get(url,
                           headers=self._auth_headers,
                           params={'application': application},
                           verify=False)
        return [x.get('name') for x in req.json()]
